# infretis
![Tests](https://github.com/infretis/infretis/actions/workflows/test.yaml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/infretis/infretis/badge.svg?branch=main)](https://coveralls.io/github/infretis/infretis?branch=main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


## Installation 

1. Clone the repository
2. (Optional) Create a virtual environment
3. Install with:
   ```bash   
   python -m pip install -e .
   ```
